@@ -12,7 +12,7 @@ from . import packet
 from . import payload
 from . import socket
 
-default_logger = logging.getLogger('engineio')
+default_logger = logging.getLogger('engineio.server')
 
 
 class Server(object):
@@ -28,7 +28,7 @@ class Server(object):
                        argument is not given, "eventlet" is tried first, then
                        "gevent_uwsgi", then "gevent", and finally "threading".
                        The first async mode that has all its dependencies
-                       installed is then one that is chosen.
+                       installed is the one that is chosen.
     :param ping_timeout: The time in seconds that the client waits for the
                          server to respond before disconnecting. The default
                          is 60 seconds.
@@ -117,7 +117,7 @@ class Server(object):
         for mode in modes:
             try:
                 self._async = importlib.import_module(
-                    'engineio.async_' + mode)._async
+                    'engineio.async_drivers.' + mode)._async
                 asyncio_based = self._async['asyncio'] \
                     if 'asyncio' in self._async else False
                 if asyncio_based != self.is_asyncio_based():
@@ -129,8 +129,8 @@ class Server(object):
         if self.async_mode is None:
             raise ValueError('Invalid async_mode specified')
         if self.is_asyncio_based() and \
-                ('asyncio' not in self._async or
-                 not self._async['asyncio']):  # pragma: no cover
+                ('asyncio' not in self._async or not
+                 self._async['asyncio']):  # pragma: no cover
             raise ValueError('The selected async_mode is not asyncio '
                              'compatible')
         if not self.is_asyncio_based() and 'asyncio' in self._async and \
